@@ -7,7 +7,6 @@ def cut(reducesize=0, figSelect='', kernelSize=0, ApplyTimes=0):
     import promptlib
     import os
     import logging
-    import subprocess
     logging.basicConfig(filename="cutmessages.log",
                         format='%(asctime)s %(message)s',
                         filemode='w')
@@ -130,10 +129,12 @@ def cut(reducesize=0, figSelect='', kernelSize=0, ApplyTimes=0):
             contour_list.append(c)
             ROI_number += 1
 
-        logger.info("Contours detected: {}".format(len(contour_list)))
+        logger.info("Contornos detectados: {}".format(len(contour_list)))
         cv2.waitKey()
         subprocess.Popen(f'explorer /select, {directory}')
-        logger.info("Delete false positive files.")
+        logger.info("Eliminar las imagenes no candidatas para el entrenamiento.")
         cv2.waitKey()
         cv2.destroyAllWindows()
-cut(reducesize=1, figSelect='square', kernelSize=0, ApplyTimes=0)
+
+if __name__ == '__main__':
+    cut()
